@@ -155,7 +155,7 @@ class Model:
 
         if elem not in self.elem_output[step][inc][var]:
             etype = self.elements[elem].elem_code
-            self.elem_output[step][inc][var][elem] = np.empty((N_INT_PNTS[etype], 1), dtype=np.float64)
+            self.elem_output[step][inc][var][elem] = np.empty((N_INT_PNTS[etype], 1), dtype=float)
 
         self.elem_output[step][inc][var][elem][intpnt - 1] = data
 
@@ -384,17 +384,22 @@ class Model:
         return coords_ar
 
     def get_element_result(self, var, step, inc, elem_set=None, elem_id=None):
-        """Get element results.
+        """get_element_result.
 
         Parameters
         ----------
-        var : TODO
-        step : TODO
-        inc : TODO
-
-        Returns
-        -------
-        TODO
+        self :
+            self
+        var :
+            var
+        step :
+            step
+        inc :
+            inc
+        elem_set :
+            elem_set
+        elem_id :
+            elem_id
 
         """
         # FIXME: have this variable sorted globally
